@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: chunked-data
 version: 0.2.0
-id: chunked-data-0.2.0-d6d31e5927728350964419b731816e7b
-key: chunk_5FMfTe2tG56KlokOcQAhrl
+id: chunked-data-0.2.0-ed90e8d1292404e980f8a818efffd356
+key: chunk_6zFxacI3dHoG5vOiEzMLm4
 license: MIT
 maintainer: michael@snoyman.com
 homepage: https://github.com/fpco/chunked-data
@@ -20,14 +20,14 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/chunked-data-0.2.0
 library-dirs: /usr/lib/ghc-7.10.3/site-local/chunked-data-0.2.0
 data-dir: /usr/share/arm-linux-ghc-7.10.3/chunked-data-0.2.0
-hs-libraries: HSchunked-data-0.2.0-5FMfTe2tG56KlokOcQAhrl
+hs-libraries: HSchunked-data-0.2.0-6zFxacI3dHoG5vOiEzMLm4
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     blaze-builder-0.4.0.1-3daa45cd3be9618b289586d273c59e36
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
-    mono-traversable-0.10.1-6e9fa89edc8b9472b6cad8340678b5ca
-    semigroups-0.18.0.1-8982ad8edd41304214263f489c2b00c2
+    mono-traversable-0.10.1-4a434efe4dfeb2b3479b76c4f64320d6
+    semigroups-0.18.1-34c490e60d2f8a8cae75b79e944c6c08
     text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
     vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
